<?php
/**
 * File_Fortune_Exception: Exception classes for {@link File_Fortune} and 
 * {@link File_Fortune_Writer}
 *
 * @package   File_Fortune
 * @author    Matthew Weier O'Phinney <mweierophinney@gmail.com>
 * @copyright 2005, Matthew Weier O'Phinney
 * @version   CVS: $Id:$
 */

/**
 * Utilize PEAR_Exception for error handling
 */
require_once 'PEAR/Exception.php';

/**
 * File_Fortune_Exception: Exception classes for {@link File_Fortune} and 
 * {@link File_Fortune_Writer}
 *
 * {@link File_Fortune} base exception class; all {@link File_Fortune} and
 * {@link File_Fortune_Writer} exceptions inherit from this class.
 *
 * @package   File_Fortune
 * @version   Release: 0.9.0
 */
class File_Fortune_Exception extends PEAR_Exception 
{
}

/**
 * File_Fortune_Exception_NoFilename is thrown whenever an attempt is made to 
 * {@link File_Fortune::open() open} a fortune file without specifying a file
 * name.
 *
 * @package File_Fortune
 */
class File_Fortune_Exception_NoFilename extends File_Fortune_Exception 
{
}

/**
 * File_Fortune_Exception_NoFile is thrown whenever an attempt is made to read
 * from an unopened file.
 *
 * @package File_Fortune
 */
class File_Fortune_Exception_NoFile extends File_Fortune_Exception 
{
}

/**
 * File_Fortune_Exception_BadFile is thrown whenever a file cannot be opened
 * (missing file, error opening file).
 *
 * @package File_Fortune
 */
class File_Fortune_Exception_BadFile extends File_Fortune_Exception 
{
}

/**
 * File_Fortune_Exception_BadHeaderFile is thrown if an error occurs opening the
 * header file or if the header file is malformed.
 *
 * @package File_Fortune
 */
class File_Fortune_Exception_BadHeaderFile extends File_Fortune_Exception 
{
}

/**
 * File_Fortune_Exception_HeaderNotRead is thrown whenever an operation requiring
 * elements obtained from the header is called and those elements are missing.
 *
 * @package File_Fortune
 */
class File_Fortune_Exception_HeaderNotRead extends File_Fortune_Exception 
{
}

/**
 * File_Fortune_Exception_InvalidCount is thrown when an attempt is made to read
 * a fortune ID that is beyond the number of fortunes available in the file, and
 * all fortunes have been previously read into {@link File_Fortune::$fortunes}.
 *
 * @package File_Fortune
 */
class File_Fortune_Exception_InvalidCount extends File_Fortune_Exception 
{
}

/**
 * File_Fortune_Exception_NotOpen is thrown when an attempt is made to read from
 * an unopened fortune file.
 *
 * @package File_Fortune
 */
class File_Fortune_Exception_NotOpen extends File_Fortune_Exception 
{
}

/**
 * File_Fortune_Exception_InvalidID is thrown when an attempt is made to read a
 * fortune ID for which there is no corresponding offset.
 *
 * @package File_Fortune
 */
class File_Fortune_Exception_InvalidID extends File_Fortune_Exception 
{
}

/**
 * File_Fortune_Exception_Offset is thrown when reading from a fortune file and
 * fseek() is unable to seek to the desired fortune offset.
 *
 * @package File_Fortune
 */
class File_Fortune_Exception_Offset extends File_Fortune_Exception 
{
}

/**
 * File_Fortune_Writer base exception class.
 *
 * @package File_Fortune
 */
class File_Fortune_Writer_Exception extends File_Fortune_Exception
{
}

/**
 * File_Fortune_Writer_Exception_FileOpen is thrown whenever fopen() is unable to
 * open a file for a write operation.
 *
 * @package File_Fortune
 */
class File_Fortune_Writer_Exception_FileOpen extends File_Fortune_Writer_Exception
{
}

/**
 * File_Fortune_Writer_Exception_FileLock is thrown whenever flock() is unable to
 * obtain a file lock.
 *
 * @package File_Fortune
 */
class File_Fortune_Writer_Exception_FileLock extends File_Fortune_Writer_Exception
{
}

/**
 * File_Fortune_Writer_Exception_FilePos is thrown whenever ftell() is unable to
 * return the current position in the file.
 *
 * @package File_Fortune
 */
class File_Fortune_Writer_Exception_FilePos extends File_Fortune_Writer_Exception
{
}
?>
